==> ngcp-rest-api_13.5.1.4+0~mr13.5.1.4.tar.xz: ngcp-rest-api-13.5.1.4+0~mr13.5.1.4/src/entities/internal/index.ts <==
export {Admin} from './admin.internal.entity'
export {AdminPasswordJournal} from './admin-password-journal.internal.entity'
export {AclRole} from './acl-role.internal.entity'
export {BanAdmin} from './ban-admin.internal.entity'
export {BanSubscriber} from './ban-subscriber.internal.entity'
export {CustomerBillingProfile} from './customer-billing-profile.internal.entity'
export {BillingNetwork} from './billing-network.internal.entity'
export {BillingProfile} from './billing-profile.internal.entity'
export {BillingMapping} from './billing-mapping.internal.entity'
export {CallId} from './call-id.internal.entity'
export {Contact} from './contact.internal.entity'
export {Contract} from './contract.internal.entity'
export {ContractBalance} from './contract-balance.internal.entity'
export {Customer} from './customer.internal.entity'
export {CustomerNumber} from './customer-number.internal.entity'
export {CustomerPhonebook} from './customer-phonebook.internal.entity'
export {CustomerSpeedDial} from './customer-speed-dial.internal.entity'
export {Domain} from './domain.internal.entity'
export {EmailTemplate} from './email-template.internal.entity'
export {HeaderRule} from './header-rule.internal.entity'
export {HeaderRuleSet} from './header-rule-set.internal.entity'
export {HeaderRuleAction} from './header-rule-action.internal.entity'
export {HeaderRuleCondition} from './header-rule-condition.internal.entity'
export {HeaderRuleConditionValue} from './header-rule-condition-value.internal.entity'
export {Journal} from './journal.internal.entity'
export {NCOSPattern} from './ncos-pattern.internal.entity'
export {NCOSLevel} from './ncos-level.internal.entity'
export {NCOSSet} from './ncos-set.internal.entity'
export {NCOSSetLevel} from './ncos-set-level.internal.entity'
export {PbxGroup} from './pbx-group.internal.entity'
export {PbxGroupMember} from './pbx-group-member.internal.entity'
export {PbxUser} from './pbx-user.internal.entity'
export {Product} from './product.internal.entity'
export {ProfilePackage} from './profile-package.internal.entity'
export {ProfilePackageSet} from './profile-package-set.internal.entity'
export {Reseller} from './reseller.internal.entity'
export {ResellerPhonebook} from './reseller-phonebook.internal.entity'
export {RewriteRuleSet} from './rewrite-rule-set.internal.entity'
export {SubscriberPhonebook} from './subscriber-phonebook.internal.entity'
export {VCustomerPhonebook} from './v-customer-phonebook.internal.entity'
export {Voicemail} from './voicemail.internal.entity'
export {VoipNumber} from './voip-number.internal.entity'
export {VoipPeeringGroup} from './voip-peering-group.internal.entity'
export {VoipPeeringServer} from './voip-peering-server.internal.entity'
export {VoipSubscriber} from './voip-subscriber.internal.entity'
export {VSubscriberPhonebook} from './v-subscriber-phonebook.internal.entity'
export {RewriteRule} from './rewrite-rule.internal.entity'
export {SubscriberWebPasswordJournal} from './voip-subscriber-webpassword-journal.internal.entity'

==> ngcp-rest-api_14.0.1.1+0~mr14.0.1.1.tar.xz: ngcp-rest-api-14.0.1.1+0~mr14.0.1.1/src/entities/internal/index.ts <==
export {Admin} from './admin.internal.entity'
export {AdminPasswordJournal} from './admin-password-journal.internal.entity'
export {AclRole} from './acl-role.internal.entity'
export {BanAdmin} from './ban-admin.internal.entity'
export {BanRegistration} from './ban-registration.internal.entity'
export {BanIp} from './ban-ip.internal.entity'
export {BanSubscriber} from './ban-subscriber.internal.entity'
export {CustomerBillingProfile} from './customer-billing-profile.internal.entity'
export {BillingNetwork} from './billing-network.internal.entity'
export {BillingProfile} from './billing-profile.internal.entity'
export {BillingMapping} from './billing-mapping.internal.entity'
export {CallId} from './call-id.internal.entity'
export {Contact} from './contact.internal.entity'
export {Contract} from './contract.internal.entity'
export {ContractBalance} from './contract-balance.internal.entity'
export {Customer} from './customer.internal.entity'
export {CustomerNumber} from './customer-number.internal.entity'
export {CustomerPhonebook} from './customer-phonebook.internal.entity'
export {CustomerSpeedDial} from './customer-speed-dial.internal.entity'
export {Domain} from './domain.internal.entity'
export {EmailTemplate} from './email-template.internal.entity'
export {HeaderRule} from './header-rule.internal.entity'
export {HeaderRuleSet} from './header-rule-set.internal.entity'
export {HeaderRuleAction} from './header-rule-action.internal.entity'
export {HeaderRuleCondition} from './header-rule-condition.internal.entity'
export {HeaderRuleConditionValue} from './header-rule-condition-value.internal.entity'
export {InvoiceTemplate} from './invoice-template.internal.entity'
export {Journal} from './journal.internal.entity'
export {NCOSPattern} from './ncos-pattern.internal.entity'
export {NCOSLevel} from './ncos-level.internal.entity'
export {NCOSSet} from './ncos-set.internal.entity'
export {NCOSSetLevel} from './ncos-set-level.internal.entity'
export {PbxGroup} from './pbx-group.internal.entity'
export {PbxGroupMember} from './pbx-group-member.internal.entity'
export {PbxUser} from './pbx-user.internal.entity'
export {Product} from './product.internal.entity'
export {ProfilePackage} from './profile-package.internal.entity'
export {ProfilePackageSet} from './profile-package-set.internal.entity'
export {Reseller} from './reseller.internal.entity'
export {ResellerPhonebook} from './reseller-phonebook.internal.entity'
export {RewriteRuleSet} from './rewrite-rule-set.internal.entity'
export {SubscriberPhonebook} from './subscriber-phonebook.internal.entity'
export {VCustomerPhonebook} from './v-customer-phonebook.internal.entity'
export {Voicemail} from './voicemail.internal.entity'
export {VoipNumber} from './voip-number.internal.entity'
export {VoipPeeringGroup} from './voip-peering-group.internal.entity'
export {VoipPeeringInboundRule} from './voip-peering-inbound-rule.internal.entity'
export {VoipPeeringRule} from './voip-peering-rule.internal.entity'
export {VoipPeeringServer} from './voip-peering-server.internal.entity'
export {VoipSubscriber} from './voip-subscriber.internal.entity'
export {VSubscriberPhonebook} from './v-subscriber-phonebook.internal.entity'
export {RewriteRule} from './rewrite-rule.internal.entity'
export {SubscriberWebPasswordJournal} from './voip-subscriber-webpassword-journal.internal.entity'
